#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2006
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# ifix launcher
thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

if [ ! "$2" ]
then
  if [  -f ./IY99644.sh ]
 then
 echo "Ifix_IY99644: WVS Ifix IY99644 Installer command syntax: "
 echo " to install ifix  syntax: ifix_IY99644 -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_IY99644.sh -uninstall "
 echo " "
 exit -1
 fi
fi

if [ $# -eq 0 ]
then
 echo "Ifix_IY99644: WVS Ifix IY99644 Installer command syntax: "
 echo " to install ifix  syntax: ifix_IY99644 -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_IY99644.sh -uninstall "
 echo " "
 exit -1
fi

if [ -f /usr/WebSphere/AppServer/bin/setupCmdLine.sh ]
then
  . /usr/WebSphere/AppServer/bin/setupCmdLine.sh
fi


if [ ! "$WAS_HOME" ] ; then
   echo "Ifix_IY99644: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "         the WAS Command line environment"
  exit -1
fi

if [ ! "$WVS_ROOT" ] ; then
   echo "Ifix_IY99644: Please configure WebSphere Voice Server wvs.setenv according"
   echo "         to the WVS InfoCenter "
  exit -1
fi


isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/IY99644/ttsmcl.bak ] ; then
    echo "Ifix_IY99644: Ifix IY99644 is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
  # Check that the ifix files are found
  echo "Ifix_IY99644: Checking for ifix files ..."
  if [ -f $thisDir/ttsmcl ] ; then
    if [ -f $thisDir/libssmlprocessor.a ] ; then
      echo "Ifix_IY99644: Ifix files found.. proceeding to install ifix"
      mkdir -p $WVS_ROOT/ifix/IY99644
      cp -p $thisDir/IY99644.sh $WVS_ROOT/ifix/ifix_IY99644.sh
      cp -p $thisDir/stopVoiceServer.jacl $WVS_ROOT/ifix/IY99644/.
      cp -p $WVS_ROOT/IBM/ibmtts/bin/ttsmcl $WVS_ROOT/ifix/IY99644/ttsmcl.bak
      cp -p $WVS_ROOT/IBM/ibmtts/lib/libjpnrom.a $WVS_ROOT/ifix/IY99644/libjpnrom.a.bak
      cp -p $WVS_ROOT/IBM/ibmtts/lib/libssmlprocessor.a $WVS_ROOT/ifix/IY99644/libssmlprocessor.a.bak


      echo "Ifix_IY99644: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1 -quiet
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_IY99644: Application Server stopped successful, proceeding to install ifix"
      else
         echo "Ifix_IY99644: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/IY99644
         exit -1
      fi

      cp -fp $thisDir/ttsmcl $WVS_ROOT/IBM/ibmtts/bin/.
      cp -fp $thisDir/libjpnrom.a $WVS_ROOT/IBM/ibmtts/lib/.
      cp -fp $thisDir/libssmlprocessor.a $WVS_ROOT/IBM/ibmtts/lib/.

      chmod 755 $WVS_ROOT/IBM/ibmtts/bin/ttsmcl
      chmod 755 $WVS_ROOT/IBM/ibmtts/lib/libjpnrom.a
      chmod 755 $WVS_ROOT/IBM/ibmtts/lib/libssmlprocessor.a

      echo "Ifix_IY99644: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_IY99644: Application Server started successful, proceeding to install ifix"
      else
         echo "Ifix_IY99644: Application Server reported failure during starting. Ifix installation was not successful. Please uninstall"
         exit -1
      fi

      echo "Ifix_IY99644: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $thisDir/stopVoiceServer.jacl $thisHostname
      errorsduringinstall=$?

#      echo "Ifix_IY99644: Updating WebSphere Voice Server J2EE Application"
#      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ear wvsapp WVS5.1-$thisHostname $thisHostname
#      errorsduringinstall=$?

      if [ $errorsduringinstall = "0" ] ; then
        echo "Ifix_IY99644: Ifix is now applied, please reboot the system"
      else
        echo "Ifix_IY99644: Ifix installation was not successful. Please uninstall. "
      fi

    else
      echo "Ifix_IY99644: Ifix files missing, please be sure this script is in same directory as the binary files"
    fi
  fi
  cp -fp $thisDir/IY99644.log $WVS_ROOT/log/.
fi

if [ "$isUnInstallOption" = "true" ] ; then
  # Check that the ifix backup files are found
  echo "Ifix_IY99644: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/IY99644/ttsmcl.bak ] ; then
    if [ -f $WVS_ROOT/ifix/IY99644/libssmlprocessor.a.bak ] ; then
      echo "Ifix_IY99644: Ifix backup files found.. proceeding to un-install ifix"

      echo "Ifix_IY99644: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_IY99644: Application Server started successful, proceeding to uninstall ifix"
      else
         echo "Ifix_IY99644: Application Server reported failure during starting. Ifix uninstallation was not successful. Please contact support"
         exit -1
      fi

      echo "Ifix_IY99644: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/ifix/IY99644/stopVoiceServer.jacl $thisHostname

      cp -fp $WVS_ROOT/ifix/IY99644/ttsmcl.bak $WVS_ROOT/IBM/ibmtts/bin/ttsmcl
      cp -fp $WVS_ROOT/ifix/IY99644/libjpnrom.a.bak  $WVS_ROOT/IBM/ibmtts/libjpnrom.a
      cp -fp $WVS_ROOT/ifix/IY99644/libssmlprocessor.a.bak  $WVS_ROOT/IBM/ibmtts/libssmlprocessor.a


      echo "Ifix_IY99644: Ifix uninstallation was successful.  "

      rm -rf $WVS_ROOT/ifix/IY99644

    else
      echo "Ifix_IY99644: Ifix backup files missing, uninstall not performed"
    fi
  else
    echo "Ifix_IY99644: Ifix backup files missing, uninstall not performed"
  fi
fi
exit $?
